==> kmp-authentication-public-0.0.1-sources.jar: commonMain/io/privy/auth/LinkedAccount.kt <==
package io.privy.auth

public sealed interface LinkedAccount {
  public data class CustomAuth(
    val customUserId: String,
    val firstVerifiedAt: Int?,
    val latestVerifiedAt: Int?
  ) : LinkedAccount

  public sealed interface EmbeddedWalletAccount: LinkedAccount {
    public val address: String
    public val chainId: String?
    public val recoveryMethod: String?
    public val hdWalletIndex: Int
  }

  public data class EmbeddedEthereumWalletAccount(
    override val address: String,
    override val chainId: String?,
    override val recoveryMethod: String?,
    override val hdWalletIndex: Int
  ) : EmbeddedWalletAccount

  public data class EmbeddedSolanaWalletAccount(
    override val address: String,
    override val chainId: String?,
    override val recoveryMethod: String?,
    override val hdWalletIndex: Int
  ) : EmbeddedWalletAccount

  public data class PhoneAccount(
    val phoneNumber: String
  ): LinkedAccount

  public data class EmailAccount(
    val emailAddress: String
  ): LinkedAccount
}

// Ethereum Embedded wallet with hdWalletIndex == 0 is the primary wallet
public fun List<LinkedAccount>.primaryEmbeddedEthereumWalletAccountOrNull(): LinkedAccount.EmbeddedEthereumWalletAccount? {
  return this.filterIsInstance<LinkedAccount.EmbeddedEthereumWalletAccount>()
    .firstOrNull { it.hdWalletIndex == 0 }
}

// Solana embedded wallet with hdWalletIndex == 0 is the primary wallet
public fun List<LinkedAccount>.primaryEmbeddedSolanaWalletAccountOrNull(): LinkedAccount.EmbeddedSolanaWalletAccount? {
  return this.filterIsInstance<LinkedAccount.EmbeddedSolanaWalletAccount>()
    .firstOrNull { it.hdWalletIndex == 0 }
}

==> kmp-authentication-public-0.0.2-sources.jar: commonMain/io/privy/auth/LinkedAccount.kt <==
package io.privy.auth

/**
 * A sealed type representing an account linked to a [PrivyUser].
 * Linked accounts can either be an authentication method, or an embedded wallet.
 * See all options below.
 */
public sealed interface LinkedAccount {
  /**
   * The linked account that represents when a user authenticates with a custom authentication method,
   */
  public data class CustomAuth(
    val customUserId: String,
    val firstVerifiedAt: Int?,
    val latestVerifiedAt: Int?
  ) : LinkedAccount

  /**
   * A base type that represents an embedded wallet. Concrete types are [EmbeddedEthereumWalletAccount]
   * and [EmbeddedSolanaWalletAccount]
   */
  public sealed interface EmbeddedWalletAccount: LinkedAccount {
    public val address: String
    public val chainId: String?
    public val recoveryMethod: String?
    public val hdWalletIndex: Int
  }

  /**
   * The linked account that represents a user's embedded Ethereum wallet
   */
  public data class EmbeddedEthereumWalletAccount(
    override val address: String,
    override val chainId: String?,
    override val recoveryMethod: String?,
    override val hdWalletIndex: Int
  ) : EmbeddedWalletAccount

  /**
   * The linked account that represents a user's embedded Solana wallet
   */
  public data class EmbeddedSolanaWalletAccount(
    override val address: String,
    override val chainId: String?,
    override val recoveryMethod: String?,
    override val hdWalletIndex: Int
  ) : EmbeddedWalletAccount

  /**
   * The linked account that represents when a user authenticates via SMS
   */
  public data class PhoneAccount(
    val phoneNumber: String
  ): LinkedAccount

  /**
   * The linked account that represents when a user authenticates via email
   */
  public data class EmailAccount(
    val emailAddress: String
  ): LinkedAccount
}

// Ethereum Embedded wallet with hdWalletIndex == 0 is the primary wallet
public fun List<LinkedAccount>.primaryEmbeddedEthereumWalletAccountOrNull(): LinkedAccount.EmbeddedEthereumWalletAccount? {
  return this.filterIsInstance<LinkedAccount.EmbeddedEthereumWalletAccount>()
    .firstOrNull { it.hdWalletIndex == 0 }
}

// Solana embedded wallet with hdWalletIndex == 0 is the primary wallet
public fun List<LinkedAccount>.primaryEmbeddedSolanaWalletAccountOrNull(): LinkedAccount.EmbeddedSolanaWalletAccount? {
  return this.filterIsInstance<LinkedAccount.EmbeddedSolanaWalletAccount>()
    .firstOrNull { it.hdWalletIndex == 0 }
}
